package com.example.nto.controller;

import com.example.nto.entity.Code;
import com.example.nto.entity.Employee;
import com.example.nto.service.EmployeeService;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

@RestController
@RequiredArgsConstructor
@RequestMapping("/api")
public class EmployeeController {
    private final EmployeeService employeeService;

    @GetMapping("/{login}/auth")
    private ResponseEntity<Void> auth(@PathVariable("login") String login) {
        return employeeService.checkExistence(login) ? new ResponseEntity<>(null, HttpStatus.OK) : new ResponseEntity<>(null, HttpStatus.UNAUTHORIZED);
    }

    @GetMapping("/{login}/info")
    private ResponseEntity<Employee> info(@PathVariable("login") String login) {
        if (!employeeService.checkExistence(login)) {
            return new ResponseEntity<>(null, HttpStatus.UNAUTHORIZED);
        }

        return new ResponseEntity<>(employeeService.info(login), HttpStatus.OK);
    }

    @PatchMapping("/{login}/open")
    private ResponseEntity<Void> open(@PathVariable("login") String login, @RequestBody Code value) {
        LocalDateTime localDateTime = LocalDateTime.now();
        if (!employeeService.checkExistence(login)) {
            return new ResponseEntity<>(null, HttpStatus.UNAUTHORIZED);
        }
        Code code = employeeService.getCode(value.getValue());
        if (code == null) {
            return new ResponseEntity<>(null, HttpStatus.BAD_REQUEST);
        }

        employeeService.updateTime(login, localDateTime);
        return new ResponseEntity<>(null, HttpStatus.OK);
    }
}
